@@ -7,18 +7,18 @@
 
   Test this function is defined:
   
-  int pthread_mutexattr_init(pthread_mutexattr_t *);
+  int pthread_mutex_trylock(pthread_mutex_t *);
   */
 
 #include <pthread.h>
 
 
-pthread_mutexattr_t a;
+pthread_mutex_t a;
 
 void dummy_func ()
 {
 
-	pthread_mutexattr_init(&a);
+	pthread_mutex_trylock(&a);
 	return;
 }
 
